@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ctrlf" "1.6"
+(define-package "ctrlf" "1.6.1"
   "Emacs finally learns how to ctrl+F."
   '((emacs "25.1"))
   :url "https://github.com/radian-software/ctrlf"
-  :commit "9b4cf6c79a961f2bfbb949805aa300fcf1eb40a6"
-  :revdesc "9b4cf6c79a96"
+  :commit "452723c046c54f66f590900548d8eb4a7783e528"
+  :revdesc "452723c046c5"
   :keywords '("extensions")
   :authors '(("Radian LLC" . "contact+ctrlf@radian.codes"))
   :maintainers '(("Radian LLC" . "contact+ctrlf@radian.codes")))
