@@ -8,8 +8,8 @@
 ;; Keywords: extensions
 ;; Package-Requires: ((emacs "25.1"))
 ;; SPDX-License-Identifier: MIT
-;; Package-Version: 1.6
-;; Package-Revision: 9b4cf6c79a96
+;; Package-Version: 1.6.1
+;; Package-Revision: 452723c046c5
 
 ;;; Commentary:
 
@@ -133,12 +133,12 @@ search already."
     (define-key keymap [remap isearch-forward] #'ctrlf-forward-default)
     (define-key keymap [remap isearch-backward] #'ctrlf-backward-default)
     (define-key keymap [remap isearch-forward-regexp]
-      #'ctrlf-forward-alternate)
+                #'ctrlf-forward-alternate)
     (define-key keymap [remap isearch-backward-regexp]
-      #'ctrlf-backward-alternate)
+                #'ctrlf-backward-alternate)
     (define-key keymap [remap isearch-forward-symbol] #'ctrlf-forward-symbol)
     (define-key keymap [remap isearch-forward-symbol-at-point]
-      #'ctrlf-forward-symbol-at-point)
+                #'ctrlf-forward-symbol-at-point)
     keymap)
   "Keymap used by CTRLF globally."
   :type 'sexp)
@@ -182,7 +182,7 @@ active in the minibuffer during a search."
     ;; Use `minibuffer-beginning-of-buffer' for Emacs >=27 and
     ;; `beginning-of-buffer' for Emacs <=26.
     (define-key keymap [remap minibuffer-beginning-of-buffer]
-      #'ctrlf-first-match)
+                #'ctrlf-first-match)
     (define-key keymap [remap beginning-of-buffer] #'ctrlf-first-match)
     (define-key keymap [remap end-of-buffer] #'ctrlf-last-match)
     (define-key keymap [remap scroll-up-command] #'ctrlf-next-page)
@@ -982,9 +982,9 @@ I have literally no idea why this is needed.")
 And self-destruct this hook."
   (remove-hook 'post-command-hook #'ctrlf--finalize)
   (unless (= (point) ctrlf--starting-point)
-    (if ctrlf-auto-recenter
-        (set-window-start (get-buffer-window) ctrlf--final-window-start)
-      (push-mark ctrlf--starting-point))))
+    (when ctrlf-auto-recenter
+      (set-window-start (get-buffer-window) ctrlf--final-window-start))
+    (push-mark ctrlf--starting-point)))
 
 (defun ctrlf--minibuffer-exit-hook ()
   "Clean up CTRLF from minibuffer and self-destruct this hook."
